==> Botania-1.16.4-411-FABRIC-20210109.224042-7-sources.jar: vazkii/botania/common/lib/LibBlockNames.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.lib;

import static vazkii.botania.common.lib.ResourceLocationHelper.prefix;

import net.minecraft.class_2960;

public final class LibBlockNames {

	public static final String MYSTICAL_FLOWER_SUFFIX = "_mystical_flower";
	public static final String ALTAR = "altar";
	public static final String APOTHECARY_PREFIX = "apothecary_";
	public static final String SPECIAL_FLOWER = "special_flower";
	public static final String LIVING_ROCK = "livingrock";
	public static final String LIVING_ROCK_BRICK = "livingrock_bricks";
	public static final String LIVING_ROCK_BRICK_MOSSY = "mossy_livingrock_bricks";
	public static final String LIVING_ROCK_BRICK_CRACKED = "cracked_livingrock_bricks";
	public static final String LIVING_ROCK_BRICK_CHISELED = "chiseled_livingrock_bricks";
	public static final String LIVING_WOOD = "livingwood";
	public static final String LIVING_WOOD_PLANKS = "livingwood_planks";
	public static final String LIVING_WOOD_PLANKS_MOSSY = "mossy_livingwood_planks";
	public static final String LIVING_WOOD_FRAMED = "framed_livingwood";
	public static final String LIVING_WOOD_PATTERN_FRAMED = "pattern_framed_livingwood";
	public static final String LIVING_WOOD_GLIMMERING = "glimmering_livingwood";
	public static final String SPREADER = "mana_spreader";
	public static final String SPREADER_REDSTONE = "redstone_spreader";
	public static final String SPREADER_ELVEN = "elven_spreader";
	public static final String SPREADER_GAIA = "gaia_spreader";
	public static final String POOL = "mana_pool";
	public static final String POOL_CREATIVE = "creative_pool";
	public static final String POOL_DILUTED = "diluted_pool";
	public static final String POOL_FABULOUS = "fabulous_pool";
	public static final String RUNE_ALTAR = "runic_altar";
	public static final String PYLON = "mana_pylon";
	public static final String PYLON_NATURA = "natura_pylon";
	public static final String PYLON_GAIA = "gaia_pylon";
	public static final String PISTON_RELAY = "piston_relay";
	public static final String DISTRIBUTOR = "mana_distributor";
	public static final String MANA_VOID = "mana_void";
	public static final String MANA_DETECTOR = "mana_detector";
	public static final String ENCHANTER = "enchanter";
	public static final String TURNTABLE = "turntable";
	public static final String TINY_PLANET = "tiny_planet_block";
	public static final String ALCHEMY_CATALYST = "alchemy_catalyst";
	public static final String OPEN_CRATE = "open_crate";
	public static final String CRAFT_CRATE = "crafty_crate";
	public static final String FOREST_EYE = "forest_eye";
	public static final String MANASTEEL_BLOCK = "manasteel_block";
	public static final String TERRASTEEL_BLOCK = "terrasteel_block";
	public static final String ELEMENTIUM_BLOCK = "elementium_block";
	public static final String MANA_DIAMOND_BLOCK = "mana_diamond_block";
	public static final String DRAGONSTONE_BLOCK = "dragonstone_block";
	public static final String DRUM_WILD = "drum_wild";
	public static final String DRUM_GATHERING = "drum_gathering";
	public static final String DRUM_CANOPY = "drum_canopy";
	public static final String SHINY_FLOWER_SUFFIX = "_shiny_flower";
	public static final String PLATFORM = "platform";
	public static final String PLATFORM_ABSTRUSE = "abstruse_platform";
	public static final String PLATFORM_SPECTRAL = "spectral_platform";
	public static final String PLATFORM_INFRANGIBLE = "infrangible_platform";
	public static final String ALF_PORTAL = "alfheim_portal";
	public static final String DREAM_WOOD = "dreamwood";
	public static final String DREAM_WOOD_PLANKS = "dreamwood_planks";
	public static final String DREAM_WOOD_PLANKS_MOSSY = "mossy_dreamwood_planks";
	public static final String DREAM_WOOD_FRAMED = "framed_dreamwood";
	public static final String DREAM_WOOD_PATTERN_FRAMED = "pattern_framed_dreamwood";
	public static final String DREAM_WOOD_GLIMMERING = "glimmering_dreamwood";
	public static final String CONJURATION_CATALYST = "conjuration_catalyst";
	public static final String BIFROST = "bifrost";
	public static final String SOLID_VINE = "solid_vine";
	public static final String BURIED_PETALS_SUFFIX = "_buried_petals";
	public static final String PRISMARINE = "prismarine";
	public static final String MINI_ISLAND = "mini_island";
	public static final String FLOATING_FLOWER_SUFFIX = "_floating_flower";
	public static final String TINY_POTATO = "tiny_potato";
	public static final String SPAWNER_CLAW = "spawner_claw";
	public static final String AZULEJO_PREFIX = "azulejo_";
	public static final String ENDER_EYE_BLOCK = "ender_eye_block";
	public static final String STARFIELD = "starfield";
	public static final String FLUXFIELD = "mana_fluxfield";
	public static final String ELF_GLASS = "elf_glass";
	public static final String BREWERY = "brewery";
	public static final String MANA_GLASS = "mana_glass";
	public static final String TERRA_PLATE = "terra_plate";
	public static final String RED_STRING_CONTAINER = "red_string_container";
	public static final String RED_STRING_DISPENSER = "red_string_dispenser";
	public static final String RED_STRING_FERTILIZER = "red_string_fertilizer";
	public static final String RED_STRING_COMPARATOR = "red_string_comparator";
	public static final String RED_STRING_RELAY = "red_string_relay";
	public static final String RED_STRING_INTERCEPTOR = "red_string_interceptor";
	public static final String FLOATING_SPECIAL_FLOWER = "floating_special_flower";
	public static final String MANA_FLAME = "mana_flame";
	public static final String PRISM = "prism";
	public static final String ENCHANTED_SOIL = "enchanted_soil";
	public static final String PETAL_BLOCK_SUFFIX = "_petal_block";
	public static final String CORPOREA_INDEX = "corporea_index";
	public static final String CORPOREA_FUNNEL = "corporea_funnel";
	public static final String MUSHROOM_SUFFIX = "_mushroom";
	public static final String PUMP = "pump";
	public static final String DOUBLE_FLOWER_SUFFIX = "_double_flower";
	public static final String STONE = "stone";
	public static final String FAKE_AIR = "fake_air";
	public static final String BLAZE_BLOCK = "blaze_block";
	public static final String CORPOREA_INTERCEPTOR = "corporea_interceptor";
	public static final String CORPOREA_CRYSTAL_CUBE = "corporea_crystal_cube";
	public static final String INCENSE_PLATE = "incense_plate";
	public static final String HOURGLASS = "hourglass";
	public static final String GHOST_RAIL = "ghost_rail";
	public static final String SPARK_CHANGER = "spark_changer";
	public static final String ROOT = "root";
	public static final String FEL_PUMPKIN = "fel_pumpkin";
	public static final String COCOON = "cocoon";
	public static final String LIGHT_RELAY = "light_relay";
	public static final String LIGHT_RELAY_SUFFIX = "_" + LIGHT_RELAY;
	public static final String LIGHT_LAUNCHER = "light_launcher";
	public static final String MANA_BOMB = "mana_bomb";
	public static final String CACOPHONIUM = "cacophonium_block";
	public static final String BELLOWS = "bellows";
	public static final String BIFROST_PERM = "bifrost_perm";
	public static final String PAVEMENT_SUFFIX = "_pavement";
	public static final String[] PAVEMENT_VARIANTS = {
			"white", "black", "blue",
			"red", "yellow", "green"
	};
	public static final String CELL_BLOCK = "cell_block";
	public static final String GAIA_HEAD = "gaia_head";
	public static final String GAIA_WALL_HEAD = "gaia_wall_head";
	public static final String CORPOREA_RETAINER = "corporea_retainer";
	public static final String TERU_TERU_BOZU = "teru_teru_bozu";
	public static final String SHIMMERROCK = "shimmerrock";
	public static final String SHIMMERWOOD_PLANKS = "shimmerwood_planks";
	public static final String AVATAR = "avatar";
	public static final String ALT_GRASS_SUFFIX = "_grass";
	public static final String ANIMATED_TORCH = "animated_torch";
	public static final String METAMORPHIC_PREFIX = "metamorphic_";
	public static final String[] METAMORPHIC_VARIANTS = {
			"forest", "plains", "mountain", "fungal",
			"swamp", "desert", "taiga", "mesa"
	};
	public static final String CORPOREA_BLOCK = "corporea_block";
	public static final String CORPOREA_SLAB = "corporea_slab";
	public static final String CORPOREA_STAIRS = "corporea_stairs";
	public static final String CORPOREA_BRICK = "corporea_brick";
	public static final String SLAB_SUFFIX = "_slab";
	public static final String STAIR_SUFFIX = "_stairs";
	public static final String WALL_SUFFIX = "_wall";
	public static final String FENCE_SUFFIX = "_fence";
	public static final String FENCE_GATE_SUFFIX = "_fence_gate";

	public static final class_2960 SUBTILE_PUREDAISY = prefix("pure_daisy");
	public static final class_2960 SUBTILE_MANASTAR = prefix("manastar");

	public static final class_2960 SUBTILE_ENDOFLAME = prefix("endoflame");
	public static final class_2960 SUBTILE_HYDROANGEAS = prefix("hydroangeas");
	public static final class_2960 SUBTILE_THERMALILY = prefix("thermalily");
	public static final class_2960 SUBTILE_ARCANE_ROSE = prefix("rosa_arcana");
	public static final class_2960 SUBTILE_MUNCHDEW = prefix("munchdew");
	public static final class_2960 SUBTILE_ENTROPINNYUM = prefix("entropinnyum");
	public static final class_2960 SUBTILE_KEKIMURUS = prefix("kekimurus");
	public static final class_2960 SUBTILE_GOURMARYLLIS = prefix("gourmaryllis");
	public static final class_2960 SUBTILE_NARSLIMMUS = prefix("narslimmus");
	public static final class_2960 SUBTILE_SPECTROLUS = prefix("spectrolus");
	public static final class_2960 SUBTILE_DANDELIFEON = prefix("dandelifeon");
	public static final class_2960 SUBTILE_RAFFLOWSIA = prefix("rafflowsia");
	public static final class_2960 SUBTILE_SHULK_ME_NOT = prefix("shulk_me_not");

	public static final class_2960 SUBTILE_BELLETHORN = prefix("bellethorn");
	public static final class_2960 SUBTILE_BERGAMUTE = prefix("bergamute");
	public static final class_2960 SUBTILE_DREADTHORN = prefix("dreadthorn");
	public static final class_2960 SUBTILE_HEISEI_DREAM = prefix("heisei_dream");
	public static final class_2960 SUBTILE_TIGERSEYE = prefix("tigerseye");
	public static final class_2960 SUBTILE_JADED_AMARANTHUS = prefix("jaded_amaranthus");
	public static final class_2960 SUBTILE_ORECHID = prefix("orechid");
	public static final class_2960 SUBTILE_FALLEN_KANADE = prefix("fallen_kanade");
	public static final class_2960 SUBTILE_EXOFLAME = prefix("exoflame");
	public static final class_2960 SUBTILE_AGRICARNATION = prefix("agricarnation");
	public static final class_2960 SUBTILE_HOPPERHOCK = prefix("hopperhock");
	public static final class_2960 SUBTILE_TANGLEBERRIE = prefix("tangleberrie");
	public static final class_2960 SUBTILE_JIYUULIA = prefix("jiyuulia");
	public static final class_2960 SUBTILE_RANNUNCARPUS = prefix("rannuncarpus");
	public static final class_2960 SUBTILE_HYACIDUS = prefix("hyacidus");
	public static final class_2960 SUBTILE_POLLIDISIAC = prefix("pollidisiac");
	public static final class_2960 SUBTILE_CLAYCONIA = prefix("clayconia");
	public static final class_2960 SUBTILE_LOONIUM = prefix("loonium");
	public static final class_2960 SUBTILE_DAFFOMILL = prefix("daffomill");
	public static final class_2960 SUBTILE_VINCULOTUS = prefix("vinculotus");
	public static final class_2960 SUBTILE_SPECTRANTHEMUM = prefix("spectranthemum");
	public static final class_2960 SUBTILE_MEDUMONE = prefix("medumone");
	public static final class_2960 SUBTILE_MARIMORPHOSIS = prefix("marimorphosis");
	public static final class_2960 SUBTILE_BUBBELL = prefix("bubbell");
	public static final class_2960 SUBTILE_SOLEGNOLIA = prefix("solegnolia");
	public static final class_2960 SUBTILE_ORECHID_IGNEM = prefix("orechid_ignem");

	public static final String MOTIF_DAYBLOOM = "daybloom_motif";
	public static final String MOTIF_NIGHTSHADE = "nightshade_motif";
	public static final String MOTIF_HYDROANGEAS = "hydroangeas_motif";

	public static final String QUARTZ_DARK = "dark_quartz";
	public static final String QUARTZ_MANA = "mana_quartz";
	public static final String QUARTZ_BLAZE = "blaze_quartz";
	public static final String QUARTZ_LAVENDER = "lavender_quartz";
	public static final String QUARTZ_RED = "red_quartz";
	public static final String QUARTZ_ELF = "elf_quartz";
	public static final String QUARTZ_SUNNY = "sunny_quartz";
	public static final String[] QUARTZ_VARIANTS = {
			QUARTZ_DARK, QUARTZ_MANA, QUARTZ_BLAZE, QUARTZ_LAVENDER,
			QUARTZ_RED, QUARTZ_ELF, QUARTZ_SUNNY
	};

}

==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/lib/LibBlockNames.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.lib;

import static vazkii.botania.common.lib.ResourceLocationHelper.prefix;

import net.minecraft.class_2960;

public final class LibBlockNames {

	public static final String MYSTICAL_FLOWER_SUFFIX = "_mystical_flower";
	public static final String ALTAR = "altar";
	public static final String APOTHECARY_PREFIX = "apothecary_";
	public static final String LIVING_ROCK = "livingrock";
	public static final String LIVING_ROCK_POLISHED = "polished_livingrock";
	public static final String LIVING_ROCK_BRICK = "livingrock_bricks";
	public static final String LIVING_ROCK_BRICK_MOSSY = "mossy_livingrock_bricks";
	public static final String LIVING_ROCK_BRICK_CRACKED = "cracked_livingrock_bricks";
	public static final String LIVING_ROCK_BRICK_CHISELED = "chiseled_livingrock_bricks";
	public static final String LIVING_WOOD_LOG = "livingwood_log";
	public static final String LIVING_WOOD_LOG_STRIPPED = "stripped_livingwood_log";
	public static final String LIVING_WOOD_LOG_GLIMMERING = "glimmering_livingwood_log";
	public static final String LIVING_WOOD_LOG_GLIMMERING_STRIPPED = "glimmering_stripped_livingwood_log";
	public static final String LIVING_WOOD = "livingwood";
	public static final String LIVING_WOOD_PLANKS = "livingwood_planks";
	public static final String LIVING_WOOD_PLANKS_MOSSY = "mossy_livingwood_planks";
	public static final String LIVING_WOOD_FRAMED = "framed_livingwood";
	public static final String LIVING_WOOD_PATTERN_FRAMED = "pattern_framed_livingwood";
	public static final String LIVING_WOOD_GLIMMERING = "glimmering_livingwood";
	public static final String LIVING_WOOD_STRIPPED = "stripped_livingwood";
	public static final String LIVING_WOOD_GLIMMERING_STRIPPED = "glimmering_stripped_livingwood";
	public static final String SPREADER = "mana_spreader";
	public static final String SPREADER_REDSTONE = "redstone_spreader";
	public static final String SPREADER_ELVEN = "elven_spreader";
	public static final String SPREADER_GAIA = "gaia_spreader";
	public static final String POOL = "mana_pool";
	public static final String POOL_CREATIVE = "creative_pool";
	public static final String POOL_DILUTED = "diluted_pool";
	public static final String POOL_FABULOUS = "fabulous_pool";
	public static final String RUNE_ALTAR = "runic_altar";
	public static final String PYLON = "mana_pylon";
	public static final String PYLON_NATURA = "natura_pylon";
	public static final String PYLON_GAIA = "gaia_pylon";
	public static final String PISTON_RELAY = "piston_relay";
	public static final String DISTRIBUTOR = "mana_distributor";
	public static final String MANA_VOID = "mana_void";
	public static final String MANA_DETECTOR = "mana_detector";
	public static final String ENCHANTER = "enchanter";
	public static final String TURNTABLE = "turntable";
	public static final String TINY_PLANET = "tiny_planet_block";
	public static final String ALCHEMY_CATALYST = "alchemy_catalyst";
	public static final String OPEN_CRATE = "open_crate";
	public static final String CRAFT_CRATE = "crafty_crate";
	public static final String FOREST_EYE = "forest_eye";
	public static final String MANASTEEL_BLOCK = "manasteel_block";
	public static final String TERRASTEEL_BLOCK = "terrasteel_block";
	public static final String ELEMENTIUM_BLOCK = "elementium_block";
	public static final String MANA_DIAMOND_BLOCK = "mana_diamond_block";
	public static final String DRAGONSTONE_BLOCK = "dragonstone_block";
	public static final String DRUM_WILD = "drum_wild";
	public static final String DRUM_GATHERING = "drum_gathering";
	public static final String DRUM_CANOPY = "drum_canopy";
	public static final String SHINY_FLOWER_SUFFIX = "_shiny_flower";
	public static final String PLATFORM = "platform";
	public static final String PLATFORM_ABSTRUSE = "abstruse_platform";
	public static final String PLATFORM_SPECTRAL = "spectral_platform";
	public static final String PLATFORM_INFRANGIBLE = "infrangible_platform";
	public static final String ALF_PORTAL = "alfheim_portal";
	public static final String DREAM_WOOD_LOG = "dreamwood_log";
	public static final String DREAM_WOOD_LOG_STRIPPED = "stripped_dreamwood_log";
	public static final String DREAM_WOOD_LOG_GLIMMERING = "glimmering_dreamwood_log";
	public static final String DREAM_WOOD_LOG_GLIMMERING_STRIPPED = "glimmering_stripped_dreamwood_log";
	public static final String DREAM_WOOD = "dreamwood";
	public static final String DREAM_WOOD_PLANKS = "dreamwood_planks";
	public static final String DREAM_WOOD_PLANKS_MOSSY = "mossy_dreamwood_planks";
	public static final String DREAM_WOOD_FRAMED = "framed_dreamwood";
	public static final String DREAM_WOOD_PATTERN_FRAMED = "pattern_framed_dreamwood";
	public static final String DREAM_WOOD_GLIMMERING = "glimmering_dreamwood";
	public static final String DREAM_WOOD_STRIPPED = "stripped_dreamwood";
	public static final String DREAM_WOOD_GLIMMERING_STRIPPED = "glimmering_stripped_dreamwood";
	public static final String CONJURATION_CATALYST = "conjuration_catalyst";
	public static final String BIFROST = "bifrost";
	public static final String SOLID_VINE = "solid_vine";
	public static final String BURIED_PETALS_SUFFIX = "_buried_petals";
	public static final String PRISMARINE = "prismarine";
	public static final String MINI_ISLAND = "mini_island";
	public static final String FLOATING_FLOWER_SUFFIX = "_floating_flower";
	public static final String TINY_POTATO = "tiny_potato";
	public static final String SPAWNER_CLAW = "spawner_claw";
	public static final String AZULEJO_PREFIX = "azulejo_";
	public static final String ENDER_EYE_BLOCK = "ender_eye_block";
	public static final String STARFIELD = "starfield";
	public static final String FLUXFIELD = "mana_fluxfield";
	public static final String ELF_GLASS = "elf_glass";
	public static final String BREWERY = "brewery";
	public static final String MANA_GLASS = "mana_glass";
	public static final String TERRA_PLATE = "terra_plate";
	public static final String RED_STRING_CONTAINER = "red_string_container";
	public static final String RED_STRING_DISPENSER = "red_string_dispenser";
	public static final String RED_STRING_FERTILIZER = "red_string_fertilizer";
	public static final String RED_STRING_COMPARATOR = "red_string_comparator";
	public static final String RED_STRING_RELAY = "red_string_relay";
	public static final String RED_STRING_INTERCEPTOR = "red_string_interceptor";
	public static final String FLOATING_SPECIAL_FLOWER = "floating_special_flower";
	public static final String MANA_FLAME = "mana_flame";
	public static final String PRISM = "prism";
	public static final String ENCHANTED_SOIL = "enchanted_soil";
	public static final String PETAL_BLOCK_SUFFIX = "_petal_block";
	public static final String CORPOREA_INDEX = "corporea_index";
	public static final String CORPOREA_FUNNEL = "corporea_funnel";
	public static final String MUSHROOM_SUFFIX = "_mushroom";
	public static final String PUMP = "pump";
	public static final String DOUBLE_FLOWER_SUFFIX = "_double_flower";
	public static final String STONE = "stone";
	public static final String FAKE_AIR = "fake_air";
	public static final String BLAZE_BLOCK = "blaze_block";
	public static final String CORPOREA_INTERCEPTOR = "corporea_interceptor";
	public static final String CORPOREA_CRYSTAL_CUBE = "corporea_crystal_cube";
	public static final String INCENSE_PLATE = "incense_plate";
	public static final String HOURGLASS = "hourglass";
	public static final String GHOST_RAIL = "ghost_rail";
	public static final String SPARK_CHANGER = "spark_changer";
	public static final String ROOT = "root";
	public static final String FEL_PUMPKIN = "fel_pumpkin";
	public static final String COCOON = "cocoon";
	public static final String LIGHT_RELAY = "light_relay";
	public static final String LIGHT_RELAY_SUFFIX = "_" + LIGHT_RELAY;
	public static final String LIGHT_LAUNCHER = "light_launcher";
	public static final String MANA_BOMB = "mana_bomb";
	public static final String CACOPHONIUM = "cacophonium_block";
	public static final String BELLOWS = "bellows";
	public static final String BIFROST_PERM = "bifrost_perm";
	public static final String PAVEMENT_SUFFIX = "_pavement";
	public static final String[] PAVEMENT_VARIANTS = {
			"white", "black", "blue",
			"red", "yellow", "green"
	};
	public static final String CELL_BLOCK = "cell_block";
	public static final String GAIA_HEAD = "gaia_head";
	public static final String GAIA_WALL_HEAD = "gaia_wall_head";
	public static final String CORPOREA_RETAINER = "corporea_retainer";
	public static final String TERU_TERU_BOZU = "teru_teru_bozu";
	public static final String SHIMMERROCK = "shimmerrock";
	public static final String SHIMMERWOOD_PLANKS = "shimmerwood_planks";
	public static final String AVATAR = "avatar";
	public static final String ALT_GRASS_SUFFIX = "_grass";
	public static final String ANIMATED_TORCH = "animated_torch";
	public static final String METAMORPHIC_PREFIX = "metamorphic_";
	public static final String[] METAMORPHIC_VARIANTS = {
			"forest", "plains", "mountain", "fungal",
			"swamp", "desert", "taiga", "mesa"
	};
	public static final String CORPOREA_BLOCK = "corporea_block";
	public static final String CORPOREA_SLAB = "corporea_slab";
	public static final String CORPOREA_STAIRS = "corporea_stairs";
	public static final String CORPOREA_BRICK = "corporea_brick";
	public static final String SLAB_SUFFIX = "_slab";
	public static final String STAIR_SUFFIX = "_stairs";
	public static final String WALL_SUFFIX = "_wall";
	public static final String FENCE_SUFFIX = "_fence";
	public static final String FENCE_GATE_SUFFIX = "_fence_gate";

	public static final class_2960 SUBTILE_PUREDAISY = prefix("pure_daisy");
	public static final class_2960 SUBTILE_MANASTAR = prefix("manastar");

	public static final class_2960 SUBTILE_ENDOFLAME = prefix("endoflame");
	public static final class_2960 SUBTILE_HYDROANGEAS = prefix("hydroangeas");
	public static final class_2960 SUBTILE_THERMALILY = prefix("thermalily");
	public static final class_2960 SUBTILE_ARCANE_ROSE = prefix("rosa_arcana");
	public static final class_2960 SUBTILE_MUNCHDEW = prefix("munchdew");
	public static final class_2960 SUBTILE_ENTROPINNYUM = prefix("entropinnyum");
	public static final class_2960 SUBTILE_KEKIMURUS = prefix("kekimurus");
	public static final class_2960 SUBTILE_GOURMARYLLIS = prefix("gourmaryllis");
	public static final class_2960 SUBTILE_NARSLIMMUS = prefix("narslimmus");
	public static final class_2960 SUBTILE_SPECTROLUS = prefix("spectrolus");
	public static final class_2960 SUBTILE_DANDELIFEON = prefix("dandelifeon");
	public static final class_2960 SUBTILE_RAFFLOWSIA = prefix("rafflowsia");
	public static final class_2960 SUBTILE_SHULK_ME_NOT = prefix("shulk_me_not");

	public static final class_2960 SUBTILE_BELLETHORN = prefix("bellethorn");
	public static final class_2960 SUBTILE_BERGAMUTE = prefix("bergamute");
	public static final class_2960 SUBTILE_DREADTHORN = prefix("dreadthorn");
	public static final class_2960 SUBTILE_HEISEI_DREAM = prefix("heisei_dream");
	public static final class_2960 SUBTILE_TIGERSEYE = prefix("tigerseye");
	public static final class_2960 SUBTILE_JADED_AMARANTHUS = prefix("jaded_amaranthus");
	public static final class_2960 SUBTILE_ORECHID = prefix("orechid");
	public static final class_2960 SUBTILE_FALLEN_KANADE = prefix("fallen_kanade");
	public static final class_2960 SUBTILE_EXOFLAME = prefix("exoflame");
	public static final class_2960 SUBTILE_AGRICARNATION = prefix("agricarnation");
	public static final class_2960 SUBTILE_HOPPERHOCK = prefix("hopperhock");
	public static final class_2960 SUBTILE_TANGLEBERRIE = prefix("tangleberrie");
	public static final class_2960 SUBTILE_JIYUULIA = prefix("jiyuulia");
	public static final class_2960 SUBTILE_RANNUNCARPUS = prefix("rannuncarpus");
	public static final class_2960 SUBTILE_HYACIDUS = prefix("hyacidus");
	public static final class_2960 SUBTILE_POLLIDISIAC = prefix("pollidisiac");
	public static final class_2960 SUBTILE_CLAYCONIA = prefix("clayconia");
	public static final class_2960 SUBTILE_LOONIUM = prefix("loonium");
	public static final class_2960 SUBTILE_DAFFOMILL = prefix("daffomill");
	public static final class_2960 SUBTILE_VINCULOTUS = prefix("vinculotus");
	public static final class_2960 SUBTILE_SPECTRANTHEMUM = prefix("spectranthemum");
	public static final class_2960 SUBTILE_MEDUMONE = prefix("medumone");
	public static final class_2960 SUBTILE_MARIMORPHOSIS = prefix("marimorphosis");
	public static final class_2960 SUBTILE_BUBBELL = prefix("bubbell");
	public static final class_2960 SUBTILE_SOLEGNOLIA = prefix("solegnolia");
	public static final class_2960 SUBTILE_ORECHID_IGNEM = prefix("orechid_ignem");
	public static final class_2960 SUBTILE_LABELLIA = prefix("labellia");

	public static final String MOTIF_DAYBLOOM = "daybloom_motif";
	public static final String MOTIF_NIGHTSHADE = "nightshade_motif";
	public static final String MOTIF_HYDROANGEAS = "hydroangeas_motif";

	public static final String QUARTZ_DARK = "dark_quartz";
	public static final String QUARTZ_MANA = "mana_quartz";
	public static final String QUARTZ_BLAZE = "blaze_quartz";
	public static final String QUARTZ_LAVENDER = "lavender_quartz";
	public static final String QUARTZ_RED = "red_quartz";
	public static final String QUARTZ_ELF = "elf_quartz";
	public static final String QUARTZ_SUNNY = "sunny_quartz";
	public static final String[] QUARTZ_VARIANTS = {
			QUARTZ_DARK, QUARTZ_MANA, QUARTZ_BLAZE, QUARTZ_LAVENDER,
			QUARTZ_RED, QUARTZ_ELF, QUARTZ_SUNNY
	};

}
